function [ S ] = Gen_Jonswap( w, N, gam, Hs, w_p, s_a, s_b )
%CALCULATE THE JONSWAP SPECTRUM FOR A SET OF SPECTRAL PARAMETERS
%   Require a predefined range of frequencies w

for i = 1 : N
    if w <= w_p
        S = (1-0.287*log(gam))*5/16*Hs^2*w_p^4*w.^(-5).*exp(-5/4*...
            (w./w_p).^(-4)).*gam.^(exp(-0.5.*((w-w_p)./(s_a*w_p)).^2));
    else
        S = (1-0.287*log(gam))*5/16*Hs^2*w_p^4*w.^(-5).*exp(-5/4*...
            (w./w_p).^(-4)).*gam.^(exp(-0.5.*((w-w_p)./(s_b*w_p)).^2));
    end

end

%% Plot spectrum
%{
figure
plot(w,S)
ylabel('Spectrum S(\omega) [m^2s]')
xlabel('Frequency \omega [rad/s]')
grid on
if Hs==1
    title({'Wave spectrum for Swell', sprintf('Hs=%1.1f, T_p=%1.2f', Hs, 2*pi/w_p)})
else
    title({'Wave spectrum for Wind sea', sprintf('Hs=%1.1f, T_p=%1.2f', Hs,2*pi/ w_p)})
end

figure
plot(2*pi./w,S)
ylabel('Spectrum S(\tau) [m^2s]')
xlabel('Period \tau [rad/s]')
grid on
if Hs<1
    title({'Wave spectrum for Swell', sprintf('Hs=%1.1f, T_p=%1.2f', Hs, 2*pi/w_p)})
else
    title({'Wave spectrum for Wind sea', sprintf('Hs=%1.1f, T_p=%1.2f', Hs,2*pi/ w_p)})
end
%}