% DEFINE PARAMETERS FOR JONSWAP SPECTRUM
% DEFINE SPECTRUM AS A FUNCTION OF FREQUENCY AND SHAPE PARAMETER
% Use w for omega

f0=1/1;                % Assume lowest period of interest Tmin = 1 s
fN = 2*f0;             % Nyquist frequency
T = 3*3600;            % 3 hour simulation    
w_min = 2*pi*1/T;      % Lowest frequency
dt = 1/4/f0;           % Time step
%N = 100;               % Number of frequency intervals
%fmin = 1/T;            % Lowest frequency
dw = 2*pi/T; %2*pi*(fN-fmin)/N;   % Frequency step

% 100-year wave condition
Hs = 2.8;              % Significant wave height
Tp = 6.6;              % Spectral peak period
omega_p = 2*pi/Tp;

%JONSWAP parameters
gam = 3.3;             % Peakedness parameter
s_a = 0.07;            % Shape parameter for w<=omega_p
s_b = 0.09;            % Shape parameter for w >omega_p


%A_gam = (1-0.287*log(gam));
%S_PM = @(w) 5/16*Hs^2*omega_p^4.*w.^(-5)*exp(-5/4*(w/omega_p)^(-4));
%fact = @(s)gam^(exp(-0.5*((w-omega_p)/(s*omega_p))^2));
%S_J = @(w,s) A_gam*S_PM*fact;

%Define spectrum as function of frequency and shape parameter
S_J = @(w,s) (1-0.287*log(gam))*5/16*Hs^2*omega_p^4.*w.^(-5)*exp(-5/4*...
    (w/omega_p)^(-4))*gam^(exp(-0.5*((w-omega_p)/(s*omega_p))^2));

% Plot spectrum
%{
values = zeros(N, 2);
values(:,1) = w_min : dw : w_min+dw*(N-1);
for i = 1: N
    w = w_min+(i-1)*dw;
    if w<=omega_p
        s = s_a;
    else
        s = s_b;
    end
    values(i,2) = S_J(w,s);
end

figure
plot(values(:,1), values(:,2), 'LineWidth', 1.5)
grid on
grid minor
title({sprintf('Wave spectrum: H_s=%1.1f, T_p=%1.1f', Hs, Tp),'\gamma=3.3, \sigma_a=0.07, \sigma_b=0.09'})
xlabel('Frequency \omega [rad/s]')
ylabel('S(\omega) [m^2s]')
%legend('\gamma=3.3, \sigma_a=0.07, \sigma_b=0.09')

%}






















%{
%Wave par
Hs_vals = [2.4, 2.5, 2.8];
Tp_vals = [5.9, 6.2,6.6];
%JONSWAP parameters
figure 
for st = 1:3
    Hs = Hs_vals(st);
    Tp = Tp_vals(st);
    
    omega_p = 2*pi/Tp;
gam = 3.3;
s_a = 0.07;
s_b = 0.09;
%A_gam = (1-0.287*log(gam));
%S_PM = @(w) 5/16*Hs^2*omega_p^4.*w.^(-5)*exp(-5/4*(w/omega_p)^(-4));
%fact = @(s)gam^(exp(-0.5*((w-omega_p)/(s*omega_p))^2));
%S_J = @(w,s) A_gam*S_PM*fact;

S_J = @(w,s) (1-0.287*log(gam))*5/16*Hs^2*omega_p^4.*w.^(-5)*exp(-5/4*(w/omega_p)^(-4))*gam^(exp(-0.5*((w-omega_p)/(s*omega_p))^2));

values = zeros(N, 2);
values(:,1) = w_min : dw : w_min+dw*(N-1);
for i = 1: N
    w = w_min+(i-1)*dw;
    if w<=omega_p
        s = s_a;
    else
        s = s_b;
    end
    values(i,2) = S_J(w,s);
end

plot(values(:,1), values(:,2), 'LineWidth', 1.5)
grid on
grid minor
title({'Wave spectrum', 'Parameters: \gamma=3.3, \sigma_a=0.07, \sigma_b=0.09'})
xlabel('Frequency \omega [rad/s]')
ylabel('S(\omega) [m^2s]')
hold on
end

for st = 1:3
    txt{st} = sprintf('H_s=%1.1f, T_p=%1.1f', Hs_vals(st), Tp_vals(st));
end
legend(txt)
%}