function [ Force_p ] =...
          Gen_linearForces( A, H, w, t, delta, epsi, Beta, x, y)
% GENERATE VECTOR OF LINEAR FORCES FOR PONTOON P
% THE FORCES ARE GIVEN IN THE LOCAL COORDINATE SYSTEM OF THE PONTOON
%   Based on wave amplitude, transfer function and phase angle between
%   surface elevation and force
%   A is a vector of wave amplitudes, H is a matrix of transfer functions,
%   delta is the phase angles between the surface elevations and force
%   epsi is the random phase angle
%   ang is the angle between the waves and the longitudinal axis of the
%   pontoon

Force_p = zeros(length(t), 6);

k = w'.^2/9.81;            % Wave number
delta= delta*pi/180;       % Phase angles in radians
for a = 1:6
    Force_p(:,a)=sum(A'.*H(:,a+1).*sin(w'.*t+...
        (-k*x*cos(Beta)-k*y*sin(Beta)).*ones(1, length(t))...
        +delta(:,a+1).*ones(length(t),1)'+epsi'.*ones(length(t),1)'));
end

% COULD ALSO IGNORE THIS PART WITH LINEAR WAVE FORCES
% Change sign of forces in order to fit the defined local coordinate system
% Positive direction in same direction as incident wave
    % Local coordinate system for pontoon angle = 0:
    %   Local x-dir in positive global y-dir
    %   Local y-dir in negative global x-dir
if Beta>=0 && Beta<pi/2
    % Will have sway in negative local y-direction
    Force_p(:,2) = -Force_p(:,2);
    Force_p(:,5) = -Force_p(:,5);
elseif Beta>=pi/2 && Beta <pi
    % Leave forces as they are
elseif Beta>=pi && Beta <3*pi/2
    Force_p(:,1) = -Force_p(:,1);
    Force_p(:,4) = -Force_p(:,4);
else
    Force_p(:,1) = -Force_p(:,1);
    Force_p(:,4) = -Force_p(:,4);
    Force_p(:,2) = -Force_p(:,2);
    Force_p(:,5) = -Force_p(:,5);
end
end
