function [TransferFunctions, PhaseAngles,N_RAO] = ...
                Read_transferFunc(angles,m_size, Pontoons)
% READ LINEAR TRANSFER FUNCTIONS
    % The RAOs obtained from WADAM are stored in .txt files
    % Each .txt file includes the RAO for the selected direction set

% Directories for the four pontoon types
Pont_type = {strcat('P1_',m_size), strcat('P2_',m_size),...
    strcat('P3_',m_size), strcat('P4_',m_size)};
%Pont_type = {'P1_1.5', 'P2_1.5', 'P3_1.5', 'P4_1.5', 'P5_ship'};

% Define a cell array for storing transfer functions
TransferFunctions = cell(1,5);
% Define a cell array for storing phase angles between amplitude and force
PhaseAngles = cell(1,5);

% Temporary matrices
RAO_ampl = zeros(40, 7, length(angles));
RAO_angle = zeros(40, 7, length(angles));

motion = {'surge', 'sway', 'heave', 'roll', 'pitch', 'yaw'}; % For title

% Generate a cell array with transfer function types to be retrieved
% Can also read transfer functions for response amplitude
% types = {'SURGE', 'SWAY', 'HEAVE', 'ROLL', 'PITCH', 'YAW'};
for a = 1:6
    types{a} = sprintf('FORCE%s',num2str(a));
end

for j = Pontoons % j is the index for pontoon type

for a = 1:6 % Index for transfer function type (DOF)
type = types{a};
file = sprintf('%s.txt',type); % Filename
    for m = 1 : length(angles) 
        
fid = fopen(fullfile('LinearTransferFunctions',Pont_type{j}, file));
C = textscan(fid,'%s %s %s %s %s %s %s %s'); % Read file as string
fclose(fid);
% Find start
starts =find(strcmp(C{1}(:), type)==1); 

% Read first line of the transfer function
for i = 4 : 8
S = char(C{i}(starts(m)));
RAO(1,i-3) = str2num(S);
end

% Read remaining lines
L = starts(2)-starts(1); % Number of lines with data
for i = 1:5
    S = char(C{i}(starts(m)+1:starts(m)+L-1));
    RAO(2:L,i) = str2num(S);
end
% Store |H(w)|
RAO_ampl(:,1,m) = 2*pi./RAO(:,1); % From period to angular frequency
RAO_ampl(:,a+1,m)= RAO(:,4);
% Store phase angles
RAO_angle(:,1,m) = 2*pi./RAO(:,1); % From period to angular frequency
RAO_angle(:,a+1,m) = RAO(:,5);
clear C fid
    end
    %{
    figure()
    for r = 1: length(angles)
    plot(2*pi./RAO_ampl(:,1,1), RAO_ampl(:,a+1,r))
    hold on
    end
    grid on
    title({sprintf('Transfur function in %s', motion{a}),...
        sprintf('Pontoon type %i',j)})
    ylabel('Transfer function H(t)')
    xlabel('Period t') 
    legend('0 deg', '10 deg', '20 deg', '30 deg', '40 deg', '50 deg',...
        '60 deg', '70 deg')
    %}
end
TransferFunctions{j} = RAO_ampl;
PhaseAngles{j} = RAO_angle;
end

N_RAO = length(RAO_ampl); % Number of lines in transfer function matrix


end

